@@ -24,7 +24,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_codepipeline.type_defs import (
     ActionExecutionFilterTypeDef,
@@ -55,7 +55,7 @@ __all__ = (
 
 class ListActionExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListActionExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+    [Paginator.ListActionExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
     """
 
     def paginate(
@@ -63,74 +63,74 @@ class ListActionExecutionsPaginator(Boto3Paginator):
         pipelineName: str,
         filter: ActionExecutionFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListActionExecutionsOutputTypeDef, None, None]:
+    ) -> Iterator[ListActionExecutionsOutputTypeDef]:
         """
-        [ListActionExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
+        [ListActionExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions.paginate)
         """
 
 
 class ListActionTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListActionTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+    [Paginator.ListActionTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
     """
 
     def paginate(
         self,
         actionOwnerFilter: Literal["AWS", "ThirdParty", "Custom"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListActionTypesOutputTypeDef, None, None]:
+    ) -> Iterator[ListActionTypesOutputTypeDef]:
         """
-        [ListActionTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
+        [ListActionTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes.paginate)
         """
 
 
 class ListPipelineExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelineExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+    [Paginator.ListPipelineExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
     """
 
     def paginate(
         self, pipelineName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPipelineExecutionsOutputTypeDef, None, None]:
+    ) -> Iterator[ListPipelineExecutionsOutputTypeDef]:
         """
-        [ListPipelineExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
+        [ListPipelineExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions.paginate)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+    [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListPipelinesOutputTypeDef, None, None]:
+    ) -> Iterator[ListPipelinesOutputTypeDef]:
         """
-        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
+        [ListPipelines.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines.paginate)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+    [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
     """
 
     def paginate(
         self, resourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListTagsForResourceOutputTypeDef, None, None]:
+    ) -> Iterator[ListTagsForResourceOutputTypeDef]:
         """
-        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
+        [ListTagsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource.paginate)
         """
 
 
 class ListWebhooksPaginator(Boto3Paginator):
     """
-    [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+    [Paginator.ListWebhooks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListWebhooksOutputTypeDef, None, None]:
+    ) -> Iterator[ListWebhooksOutputTypeDef]:
         """
-        [ListWebhooks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
+        [ListWebhooks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks.paginate)
         """
